:mod:`trac.util.translation`
============================

.. automodule :: trac.util.translation
   :members:

Functions
---------

.. autofunction :: deactivate
.. autofunction :: reactivate
.. autofunction :: make_activable
.. autofunction :: get_available_locales
.. autofunction :: domain_functions
.. autofunction :: s_dgettext
.. autofunction :: s_gettext

Internals
---------

.. autoclass :: NullTranslationsBabel

.. autoclass :: TranslationsProxy
